@@ -15,6 +15,10 @@ class Point(PClass):
     z = field(type=int, initial=0)
 
 
+class Hierarchy(PClass):
+    point = field(type=Point)
+
+
 class TypedContainerObj(PClass):
     map = pmap_field(str, str)
     set = pset_field(str)
@@ -39,6 +43,13 @@ def test_create_ignore_extra_false():
         _ = Point.create({'x': 5, 'y': 10, 'z': 15, 'a': 0})
 
 
+def test_create_ignore_extra_true():
+    h = Hierarchy.create(
+        {'point': {'x': 5, 'y': 10, 'z': 15, 'extra_field_0': 'extra_data_0'}, 'extra_field_1': 'extra_data_1'},
+        ignore_extra=True)
+    assert isinstance(h, Hierarchy)
+
+
 def test_evolve_pclass_instance():
     p = Point(x=1, y=2)
     p2 = p.set(x=p.x+2)
